---
name: Bug report
about: Create a report to help us improve
title: ''
labels: bug
assignees: ''

---

**Describe the bug**
A clear and concise description of what the bug is.

**To Reproduce**
Add source code

```python
from propan import PropanApp
...
```

And steps to reproduce the behavior:

1. ...

**Expected behavior**
A clear and concise description of what you expected to happen.

**Screenshots**
If applicable, add screenshots to help explain your problem.

**Environment**
Add `propan -v` command output to show your current project and system environment

**Additional context**
Add any other context about the problem here.
